<?php

//for dealing with employees table
class EmployeeController extends Zend_Controller_Action
{

    public function init()
    {
        /* Initialize action controller here */
        //this will boot people out if they're not logged in
        $auth = Zend_Auth::getInstance();
        if( !$auth->hasIdentity() )
        {
             // display login box
            return $this->_helper->redirector('login', 'Authorize');
        }

    }

    public function indexAction()
    {
        // action body (original, just displays employees)
        $dbStuff = new Zend_Session_Namespace('dbStuff');
        $search = $dbStuff->search;
        $startFrom = $dbStuff->startFrom;
        if(isset($_GET['startFrom'])){//paging
                $startFrom = $_GET['startFrom'];
                $dbStuff->startFrom = $startFrom;
        }
        $employee = new Application_Model_EmployeeMapper();
        //get the count
        $dbStuff->count = $employee->getCount($search);
        //get the records
        $this->view->employees = $employee->getAllEmployees($search, $startFrom);
    }

    public function addAction()
    {
        // action body (to create an employee)
        $dbStuff = new Zend_Session_Namespace('dbStuff');
        $dbStuff->search = ""; // reset search
        $dbStuff->startFrom = 0; //reset paging
        $request = $this->getRequest();
        $form    = new Application_Form_EmployeeInsert();
 
        //if cancel button was pressed, we're done
        $form->populate($request->getPost());
        if ($form->cancel->isChecked())
                return $this->_helper->redirector('index');
        
        //if posting and valid, add employee
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                $emp = new Application_Model_Employee();
                //GET INFO FROM FIELDS
                $emp->setFirstName($form->getValue("first_name"));
                $emp->setLastName($form->getValue("last_name"));
                $emp->setGender($form->getValue("gender"));
                $birthdate = ($form->getValue("byear")) . "-" . ($form->getValue("bmonth")) . "-" . ($form->getValue("bday"));
                $emp->setBD($birthdate);
                $hiredate = ($form->getValue("hyear")) . "-" . ($form->getValue("hmonth")) . "-" . ($form->getValue("hday"));
                $emp->setHD($hiredate);
                $mapper  = new Application_Model_EmployeeMapper();
                $dbStuff->rowsaff = $mapper->save($emp);
                return $this->_helper->redirector('index');
            }
        }
 
        $this->view->form = $form;
    }

    public function changeAction()
    {
        // action body (to edit an employee)
        $dbStuff = new Zend_Session_Namespace('dbStuff');
        $dbStuff->search = ""; // reset search
        $dbStuff->startFrom = 0; //reset paging
        if(isset($_GET['idUpdate']))
                if(is_numeric($_GET['idUpdate']))
                {
                        $dbStuff->updateFor = $_GET['idUpdate'];
                }
                               
        //if no ID provided and not posting the update, stop
        if ($dbStuff->updateFor == "" && !$this->getRequest()->isPost())
            return $this->_helper->redirector('index');

        //I actually need now to get an employee for this id
        $empmap = new Application_Model_EmployeeMapper();
        
        $request = $this->getRequest();
        $form    = new Application_Form_EmployeeUpdate();
        
        //if cancel button was pressed, we're done
        $form->populate($request->getPost());
        if ($form->cancel->isChecked())
                return $this->_helper->redirector('index');
        
        //if posting...
        if ($this->getRequest()->isPost()) {
            //if form passes validation, make changes
            if ($form->isValid($request->getPost())) {
                if ($form->cancel->isChecked())
                return $this->_helper->redirector('index');
                $emp = new Application_Model_Employee();
                //GET INFO FROM FIELDS
                $emp->setID($form->getValue("emp_no")); //readonly on the form
                $emp->setFirstName($form->getValue("first_name"));
                $emp->setLastName($form->getValue("last_name"));
                $emp->setGender($form->getValue("gender"));
                $birthdate = ($form->getValue("byear")) . "-" . ($form->getValue("bmonth")) . "-" . ($form->getValue("bday"));
                $emp->setBD($birthdate);
                $hiredate = ($form->getValue("hyear")) . "-" . ($form->getValue("hmonth")) . "-" . ($form->getValue("hday"));
                $emp->setHD($hiredate);
                $mapper  = new Application_Model_EmployeeMapper();
                $dbStuff->rowsaff = $mapper->save($emp);
                $dbStuff->updateFor = "";
                return $this->_helper->redirector('index');
            }
        }
 
        //populate form
        $this->view->form = $form;
        $fetchedemp = $empmap->getEmployee($dbStuff->updateFor);
        $birthdatewhole = $fetchedemp->getBD();
        $bdchunks = explode("-", $birthdatewhole);
        $hiredatewhole = $fetchedemp->getHD();
        $hdchunks = explode("-", $hiredatewhole);
        $data = array( 'emp_no' => $fetchedemp->getID(), 'first_name' => $fetchedemp->getFirstName(), 'last_name' => $fetchedemp->getLastName(),
            'gender' => $fetchedemp->getGender(), 'byear' => $bdchunks[0], 'bmonth' => $bdchunks[1], 'bday' => $bdchunks[2],
            'hyear' => $hdchunks[0], 'hmonth' => $hdchunks[1], 'hday' => $hdchunks[2]);
        $this->view->form->populate($data);
    }

    public function removeAction()
    {
        // action body (to delete an employee)
        $dbStuff = new Zend_Session_Namespace('dbStuff');
        $dbStuff->search = ""; // reset search
        $dbStuff->startFrom = 0; //reset paging
        $deleteID = "";
        if(isset($_GET['idDelete']))
                if(is_numeric($_GET['idDelete']))
                        $deleteID = $_GET['idDelete'];
                               
                
        if ($deleteID == "" && !$this->getRequest()->isPost())
            return $this->_helper->redirector('index');//if empty request, stop

        //I actually need now to get an employee for this id
        $empmap = new Application_Model_EmployeeMapper();
                
        $request = $this->getRequest();
        $form    = new Application_Form_EmployeeDelete();
        
        //if cancel button was pressed, we're done
        $form->populate($request->getPost());
        if ($form->cancel->isChecked())
                return $this->_helper->redirector('index');
        
        //if form is posted and valid, do the delete
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                $emp = new Application_Model_Employee();
                $emp->setID($form->getValue("emp_no"));//all we really need out of the form
                $mapper  = new Application_Model_EmployeeMapper();
                $dbStuff->rowsaff = $mapper->deleteEmployee($emp->getID());
                return $this->_helper->redirector('index');
            }
        }
 
        //populate form (everything will be read-only)
        $this->view->form = $form;
        $fetchedemp = $empmap->getEmployee($deleteID);
        $birthdatewhole = $fetchedemp->getBD();
        $bdchunks = explode("-", $birthdatewhole);
        $hiredatewhole = $fetchedemp->getHD();
        $hdchunks = explode("-", $hiredatewhole);
        $data = array( 'emp_no' => $fetchedemp->getID(), 'first_name' => $fetchedemp->getFirstName(), 'last_name' => $fetchedemp->getLastName(),
            'gender' => $fetchedemp->getGender(), 'byear' => $bdchunks[0], 'bmonth' => $bdchunks[1], 'bday' => $bdchunks[2],
            'hyear' => $hdchunks[0], 'hmonth' => $hdchunks[1], 'hday' => $hdchunks[2]);
        $this->view->form->populate($data);
    }

    public function searchAction()
    {
        // action body (new search entered)
        $dbStuff = new Zend_Session_Namespace('dbStuff');
        $search = "";
        if(isset($_POST['search'])){
                $search = $_POST['search'];
                $dbStuff->search = $search;
        }
        $startFrom = 0;
        $dbStuff->startFrom = $startFrom; //reset paging
        $employee = new Application_Model_EmployeeMapper();
        //get the count
        $dbStuff->count = $employee->getCount($search);
        //get the records
        $this->view->employees = $employee->getAllEmployees($search, $startFrom);
        //show the main page again
        $this->render("index");
    }

    public function resetAction()
    {
        // action body (reset search and startfrom)
        $dbStuff = new Zend_Session_Namespace('dbStuff');
        $dbStuff->search = "";
        $dbStuff->startFrom = 0;
        $search = $dbStuff->search;
        $startFrom = $dbStuff->startFrom;
        $employee = new Application_Model_EmployeeMapper();
        //get the count
        $dbStuff->count = $employee->getCount($search);
        //get the records
        $this->view->employees = $employee->getAllEmployees($search, $startFrom);
        //show the main page again
        $this->render("index");
        
    }


}











