<?php
//links employees in db to rest of application
class Application_Model_EmployeeMapper
{
    
    //has a zend db table
    protected $_dbTable;
     
    //get and set zend db table
    //see: http://framework.zend.com/manual/1.12/en/learning.quickstart.create-model.html
        public function setDbTable($dbTable)
        {
            if (is_string($dbTable)) {
                $dbTable = new $dbTable();
            }
            if (!$dbTable instanceof Zend_Db_Table_Abstract) {
                throw new Exception('Invalid table data gateway provided');
            }
            $this->_dbTable = $dbTable;
            return $this;
        }
     
        public function getDbTable()
        {
            if (null === $this->_dbTable) {
                $this->setDbTable('Application_Model_DbTable_Employees');
            }
            return $this->_dbTable;
        }
        
    //get number of employees (that match search, if applicable)
    //essential for display and paging
    public function getCount($search)
    {
             
        $select = $this->getDbTable()->select();
        $select->from('employees', 'count(*) as amount');
        if ($search != "")
            $select->where("CONCAT(first_name, ' ', last_name) LIKE '%" . $search . "%'");
        $rows = $this->getDbTable()->fetchAll($select);
        return($rows[0]->amount);       
        
    }
        
    //get every employee (well, within the numerical limit (that matches search, if applicable))
    //startFrom is the record to start getting employees from, essential for paging
    //returns an array of employee objects
    public function getAllEmployees($search, $startFrom)
    {
            $where = null;
            if ($search != "")
                $where = "CONCAT(first_name, ' ', last_name) LIKE '%" . $search . "%'";
            $order = "emp_no ASC";
            $limit = 25;
            $offset = $startFrom;
            $resultSet = $this->getDbTable()->fetchAll($where,$order,$limit,$offset);
            $entries = array();
            foreach ($resultSet as $row) {
                $entry = new Application_Model_Employee();
                $entry->setID($row->emp_no);
                $entry->setBD($row->birth_date);
                $entry->setHD($row->hire_date);
                $entry->setGender($row->gender);
                $entry->setFirstName($row->first_name);
                $entry->setLastName($row->last_name);
                $entries[] = $entry;
            }
            return $entries;            
        
    }
    
    //returns a single employee object
    public function getEmployee($empID)
    {
            $result = $this->getDbTable()->find($empID);

                $entry = new Application_Model_Employee();
                $entry->setID($result[0]->emp_no);
                $entry->setBD($result[0]->birth_date);
                $entry->setHD($result[0]->hire_date);
                $entry->setGender($result[0]->gender);
                $entry->setFirstName($result[0]->first_name);
                $entry->setLastName($result[0]->last_name);

            return $entry;
        
    }
    
    //delete an employee
    public function deleteEmployee($empID)
    {
            return $this->getDbTable()->delete($empID);
        
    }
    
    //save a new employee or a change
    public function save(Application_Model_Employee $emp)
        {
            $rowsAffected = "";
            $data = array(
                'birth_date' => $emp->getBD(),
                'first_name'   => $emp->getFirstName(),
                'last_name' => $emp->getLastName(),
                'gender' => $emp->getGender(),
                'hire_date' => $emp->getHD()
            );
     
            //if no id, it's a new insert
            if (null === ($id = $emp->getID())) {
                unset($data['emp_no']);
                $rowsAffected = $this->getDbTable()->insert($data);
            } else {//it's an update
                $rowsAffected = $this->getDbTable()->update($data, $id);
            }
            return $rowsAffected;
        }

}

